@@ -381,7 +381,7 @@ void ScriptEngine::importFile(const QString &filePath, QScriptValue &targetObjec
     if (Q_UNLIKELY(!file.open(QFile::ReadOnly)))
         throw ErrorInfo(tr("Cannot open '%1'.").arg(filePath));
     QTextStream stream(&file);
-    stream.setCodec("UTF-8");
+    setupDefaultCodec(stream);
     const QString sourceCode = stream.readAll();
     file.close();
     m_currentDirPathStack.push(FileInfo::path(filePath));
@@ -478,19 +478,18 @@ QScriptValue ScriptEngine::js_require(QScriptContext *context, QScriptEngine *qt
             return context->throwError(
                         ScriptEngine::tr("require: internal error. No search paths."));
 
-        const QString uri = moduleName;
         if (engine->m_logger.debugEnabled()) {
             engine->m_logger.qbsDebug()
-                    << "[require] loading extension " << uri;
+                    << "[require] loading extension " << moduleName;
         }
 
-        QString uriAsPath = uri;
-        uriAsPath.replace(QLatin1Char('.'), QLatin1Char('/'));
+        QString moduleNameAsPath = moduleName;
+        moduleNameAsPath.replace(QLatin1Char('.'), QLatin1Char('/'));
         const QStringList searchPaths = engine->m_extensionSearchPathsStack.top();
-        const QString dirPath = findExtensionDir(searchPaths, uriAsPath);
+        const QString dirPath = findExtensionDir(searchPaths, moduleNameAsPath);
         if (dirPath.isEmpty()) {
-            if (uri.startsWith(QStringLiteral("qbs.")))
-                return loadInternalExtension(context, engine, uri);
+            if (moduleName.startsWith(QStringLiteral("qbs.")))
+                return loadInternalExtension(context, engine, moduleName);
         } else {
             QDirIterator dit(dirPath, StringConstants::jsFileWildcards(),
                              QDir::Files | QDir::Readable);
@@ -609,8 +608,8 @@ Set<QString> ScriptEngine::imports() const
         for (const QString &filePath : jsImport.filePaths)
             filePaths << filePath;
     }
-    for (auto it = m_filePathsPerImport.cbegin(); it != m_filePathsPerImport.cend(); ++it) {
-        for (const QString &fp : it->second)
+    for (const auto &kv : m_filePathsPerImport) {
+        for (const QString &fp : kv.second)
             filePaths << fp;
     }
     return filePaths;
@@ -817,9 +816,11 @@ void ScriptEngine::uninstallImportFunctions()
     globalObject().setProperty(requireString(), QScriptValue());
 }
 
-ScriptEngine::PropertyCacheKey::PropertyCacheKey(const QString &moduleName,
-        const QString &propertyName, const PropertyMapConstPtr &propertyMap)
-    : m_moduleName(moduleName), m_propertyName(propertyName), m_propertyMap(propertyMap)
+ScriptEngine::PropertyCacheKey::PropertyCacheKey(QString moduleName,
+        QString propertyName, PropertyMapConstPtr propertyMap)
+    : m_moduleName(std::move(moduleName))
+    , m_propertyName(std::move(propertyName))
+    , m_propertyMap(std::move(propertyMap))
 {
 }
 
